#!/usr/bin/perl

# CWcal installer
# by Joel Savignon

use strict;

sub cancel
{
    my $code = shift;
    print "\n**********************************\n";
    printf "*** Installation canceled (%02d) ***\n", $code;
    print "**********************************\n\n";
    exit $code;
}

my $wcalddir = "/usr/local/bin";
print "CWcal installer\n";
print "Please select the location of your wcald file\n";
print "($wcalddir) : ";
my $str = <STDIN>;
chomp($str);
if ($str)
{
    $wcalddir = $str;
}

if (!-e "$wcalddir/wcald")
{
    print "No $wcalddir/wcald file\n";
    cancel(1);
}

my $lang = "en";
print "Please select language used by CWcal (en = English, fr = French)\n";
print "($lang) : ";
$str = <STDIN>;
chomp($str);
if ($str eq "fr")
{
    $lang = $str;
}

my $wcuser = "wcal";
print "Please enter the unix user that runs wcald\n";
print "($wcuser) : ";
$str = <STDIN>;
chomp($str);
if ($str)
{
    $wcuser = $str;
}
my ($wcname,$wcpwd,$wcuid,$wcgid,$wcquota,$wccomment,$wcgcos,$wcdir) = getpwnam($wcuser);
if (!$wcuid)
{
    print "User $wcuser not found\n";
    cancel(2);
}

my $wwwuser = "apache";
print "Please enter the unix user that runs apache\n";
print "($wwwuser) : ";
$str = <STDIN>;
chomp($str);
if ($str)
{
    $wwwuser = $str;
}
my ($wwwname,$wwwpwd,$wwwuid,$wwwgid) = getpwnam($wwwuser);
if (!$wwwuid)
{
    print "User $wwwuser not found\n";
    cancel(3);
}

if ($wcgid ne $wwwgid)
{
    print "Users $wcuser and $wwwuser don't belong to the same group\n";
    cancel(4);
}

my $group = getgrgid($wcgid);
if (!$wcgid)
{
    print "Invalid group $wcgid\n";
    cancel(5);
}

my $wwwdir = "/var/www/html/cwcal";
print "Please enter the web directory to install CWcal\n";
print "($wwwdir) : ";
$str = <STDIN>;
chomp($str);
if ($str)
{
    $wwwdir = $str;
}

$wwwdir =~ s/[\/\s]*$//;

if (-e $wwwdir)
{
    print "Directory $wwwdir already exists\n";
    cancel(6);
}

if (!mkdir($wwwdir, 0750))
{
    print "Unable to create directory $wwwdir ($!)\n";
    cancel(7);
}

system("cp -r http/* $wwwdir");

if (!open(CONF, ">$wwwdir/inc/cwcal.conf"))
{
    print "Unable to create CWcal conf file $wwwdir/inc/cwcal.conf ($!)\n";
    cancel(8);
}
print CONF "lang = $lang\n";
print CONF "wcal bin = $wcalddir/wcald\n";
close(CONF);

my $wcuserfile = "$wcdir/users";
print "Please enter the users authentication file (optional)\n";
print "($wcuserfile) : ";
$str = <STDIN>;
chomp($str);
if ($str)
{
    $wcuserfile = $str;
}

my $wcgroupfile = "$wcdir/groups";
print "Please enter the groups authentication file (optional)\n";
print "($wcgroupfile) : ";
$str = <STDIN>;
chomp($str);
if ($str)
{
    $wcgroupfile = $str;
}

if (!open(CONF, ">$wwwdir/inc/cwaccess.tmpl"))
{
    print "Unable to create CWcal access template file $wwwdir/inc/cwaccess.tmpl ($!)\n";
    cancel(9);
}
print CONF "AuthType Basic\n";
print CONF "AuthName \"Wcal\"\n";
print CONF "AuthUserFile $wcuserfile\n";
print CONF "AuthGroupFile $wcgroupfile\n";
print CONF "Require valid-user\n";
close(CONF);

system("chown -R $wcname $wwwdir;chgrp -R $group $wwwdir;chmod -R 750 $wwwdir");

if (!open(WCALD, "$wcalddir/wcald"))
{
    print "Unable to open wcald file $wcalddir/wcald ($!)\n";
    cancel(10);
}
my $line;
my $wcconf;
while ($line = <WCALD>)
{
    if ($line =~ /\$\:\:CONF_FILE\s*=\s*\'([^\']+)\'/)
    {
	$wcconf = $1;
	last;
    }
}
close(WCALD);
if (!$wcconf)
{
    print "Invalid wcald file $wcalddir/wcald\n";
    cancel(11);
}
if (!-e $wcconf)
{
    print "No Wcal conf file $wcconf\n";
    cancel(12);
}
if (!chown($wwwuid,$wwwgid,$wcconf))
{
    print "Unable to change owner of $wcconf to $wwwuser\n";
    cancel(13);
}

print "\n$wcconf now belongs to user $wwwuser\n";
print "CWcal has been installed to $wwwdir\n";
print "CWcal conf file $wwwdir/inc/cwcal.conf has been created\n";
print "CWcal access template file $wwwdir/inc/cwaccess.tmpl has been created\n";
print "\nDon't forget to change Apache configuration\n";
print " - to allow ExecCGI on $wwwdir\n";
print " - to deny access to $wwwdir/inc\n";
print " - to restrict access to $wwwdir to users allowed to configure Wcal\n";
print ("\nCWcal successfully installed\n");
