#!/usr/bin/perl

# DWcal updater
# by Joel Savignon

use strict;

my $force = 0;
if ($ARGV[0] eq "-f")
{
    $force = 1;
}

my $wcalddir = "/usr/local/bin";
print "DWcal updater\n";
print "Please select the location of your wcald file\n";
print "($wcalddir) : ";
my $dir = <STDIN>;
chomp($dir);
if ($dir)
{
    $wcalddir = $dir;
}

if (!-e "$wcalddir/wcald")
{
    print "\n*** No $wcalddir/wcald file! ***\n";
    print "Install canceled\n";
    exit 1;
}

my ($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcalddir/wcald");
my $line;
if (!open(WCALD, "$wcalddir/wcald"))
{
    print "\n*** Unable to open $wcalddir/wcald file! ***\n";
    print "Install canceled\n";
    exit 2;
}
my $wcaldvers;
my $wcalddbdir;
$wcaldmode = $wcaldmode & 0777;

print "wcal uid : $wcalduid\n";
print "wcal gid : $wcaldgid\n";
printf "wcal mod : %o\n", $wcaldmode;

while ($line = <WCALD>)
{
    if ($line =~ /^\$::VERSION\s*=\s*\"([^\"]*)/)
    {
	$wcaldvers = $1+0;
	print "wcal ver : $wcaldvers\n";
    }
    elsif ($line =~ /^\$::DB_DIR\s*=\s*\'([^\']*)/)
    {
	$wcalddbdir = $1;
	print "data dir : $wcalddbdir\n";
    }
}
close(WCALD);

if (!$force && $wcaldvers < 2.2)
{
    print "\n*** Current version ($wcaldvers) of wcal must be at least 2.2 ***\n";
    print "Install canceled\n";
    exit 3;
}

print ("Copying dwcal\n");
open(DWCAL2, ">$wcalddir/dwcal");
open(DWCAL, "dwcal.in");
while ($line = <DWCAL>)
{
    $line =~ s/_X_DATA/$wcalddbdir/g;
    print DWCAL2 $line;
}
close(DWCAL);
close(DWCAL2);
chown($wcalduid, $wcaldgid, "$wcalddir/dwcal");
chmod($wcaldmode, "$wcalddir/dwcal");

print ("\nDWcal successfully updated\n");
