#!/usr/bin/perl

# S*Wcal installer
# by Joel Savignon

use strict;

my $force = 0;
if ($ARGV[0] eq "-f")
{
    $force = 1;
}

my $wcalddir = "/usr/local/bin";
print "S*Wcal installer\n";
print "Please select the location of your wcald file\n";
print "($wcalddir) : ";
my $dir = <STDIN>;
chomp($dir);
if ($dir)
{
    $wcalddir = $dir;
}

if (!-e "$wcalddir/wcald")
{
    print "\n*** No $wcalddir/wcald file! ***\n";
    print "Install canceled\n";
    exit 1;
}

my ($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcalddir/wcald");
my $line;
if (!open(WCALD, "$wcalddir/wcald"))
{
    print "\n*** Unable to open $wcalddir/wcald file! ***\n";
    print "Install canceled\n";
    exit 2;
}
my $wcaldvers;
my $wcaldconfdir;
my $wcaldhttpdir;
my $wcalddbdir;
$wcaldmode = $wcaldmode & 0777;

print "wcal uid : $wcalduid\n";
print "wcal gid : $wcaldgid\n";
printf "wcal mod : %o\n", $wcaldmode;

while ($line = <WCALD>)
{
    if ($line =~ /^\$::VERSION\s*=\s*\"([^\"]*)/)
    {
	$wcaldvers = $1+0;
	print "wcal ver : $wcaldvers\n";
    }
    elsif ($line =~ /^\$::CONF_FILE\s*=\s*\'([^\']*)\/wcal.conf/)
    {
	$wcaldconfdir = $1;
	print "conf dir : $wcaldconfdir\n";
    }
    elsif ($line =~ /^\$::DIRECTORY\s*=\s*\'([^\']*)/)
    {
	$wcaldhttpdir = $1;
	print "http dir : $wcaldhttpdir\n";
    }
    elsif ($line =~ /^\$::DB_DIR\s*=\s*\'([^\']*)/)
    {
	$wcalddbdir = $1;
	print "data dir : $wcalddbdir\n";
    }
}
close(WCALD);

if (!$force && $wcaldvers < 2.2)
{
    print "\n*** Current version ($wcaldvers) of wcal must be at least 2.2 ***\n";
    print "Install canceled\n";
    exit 3;
}

print ("Copying swcald\n");
open(SWCALD2, ">$wcalddir/swcald");
open(SWCALD, "swcald.in");
while ($line = <SWCALD>)
{
    $line =~ s/_X_CONF/$wcaldconfdir/g;
    $line =~ s/_X_DATA/$wcalddbdir/g;
    print SWCALD2 $line;
}
close(SWCALD);
close(SWCALD2);
chown($wcalduid, $wcaldgid, "$wcalddir/swcald");
chmod($wcaldmode, "$wcalddir/swcald");

print ("Copying swcal.msg\n");
($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcaldconfdir/wcal.msg");
system("cp swcal.msg $wcaldconfdir/swcal.msg");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/swcal.msg");
chmod($wcaldmode, "$wcaldconfdir/swcal.msg");

if (!-e "$wcaldconfdir/swcal.conf")
{
    print ("Copying swcal.conf\n");
    system("cp swcal.conf $wcaldconfdir/swcal.conf");
    chown($wcalduid, $wcaldgid, "$wcaldconfdir/swcal.conf");
    chmod($wcaldmode, "$wcaldconfdir/swcal.conf");
}

print ("\nS*Wcal successfully installed\n");
